==> joounit-0.9.5.jar: joo/classes/flexunit/textui/ResultPrinter.js <==
joo.classLoader.prepare(/*
	Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.textui",/*
{

   import flash.utils.*;
   import flexunit.framework.*;
   import flexunit.utils.*;*/

   "public class ResultPrinter implements flexunit.framework.TestListener, flexunit.textui.Printer",1,function($$private){var trace=joo.trace;return[
   
       "public function ResultPrinter",function ResultPrinter$()
       {/*
           super()*/;
           this._progress$1 = "";
       },

   //------------------------------------------------------------------------------

       "public function print",function print( result/*:TestResult*/, runTime/*:Number*/ )/*:void*/
       {
           if ( this._progress$1.length > 0 )
               trace( this._progress$1 );

           this.printHeader(runTime);
           this.printErrors(result);
           this.printFailures(result);
           this.printFooter$1(result);
       },

   //------------------------------------------------------------------------------

       "public function printHeader",function printHeader( runTime/*:Number*/ )/*:void*/
       {
           trace( "Time: " + ( runTime / 1000 ) + " seconds" );
       },

   //------------------------------------------------------------------------------

       "public function printErrors",function printErrors( result/*:TestResult*/ )/*:void*/
       {
           this.printDefects( result.errorsIterator(), result.errorCount(), "error" );
       },

   //------------------------------------------------------------------------------

       "public function printFailures",function printFailures( result/*:TestResult*/ )/*:void*/
       {
           this.printDefects( result.failuresIterator(), result.failureCount(), "failure" );
       },

   //------------------------------------------------------------------------------

       "public function printDefects",function printDefects( defects/*:Iterator*/, count/*:Number*/, type/*:String*/ )/*:void*/
       {
           if ( count == 0 )
               return;

           if ( count == 1 )
               trace( "There was " + count + " " + type + ":" );
           else
               trace( "There were " + count + " " + type + "s:");

           for ( var i/*:Number*/ = 1; defects.hasNext(); i++)
           {
               this.printDefect$1(/* flexunit.framework.TestFailure*/( defects.next() ), i );
           }
       },

   //------------------------------------------------------------------------------

       "private function printDefect",function printDefect( defect/*:TestFailure*/, count/*:Number*/ )/*:void*/
       {
           this.printDefectHeader$1( defect, count );
           this.printDefectTrace$1( defect );
       },

   //------------------------------------------------------------------------------

       "private function printDefectHeader",function printDefectHeader( defect/*:TestFailure*/, count/*:Number*/ )/*:void*/
       {
           trace( count + ") " + defect.failedTest().toString() );
       },

   //------------------------------------------------------------------------------

       "private function printDefectTrace",function printDefectTrace( defect/*:TestFailure*/ )/*:void*/
       {
           trace( "\t" + defect.exceptionMessage() );
       },

   //------------------------------------------------------------------------------

       "private function printFooter",function printFooter( result/*:TestResult*/ )/*:void*/
       {
           if ( result.wasSuccessful() )
           {
               trace( "" );
               trace( "OK (" + result.runCount() + " test" + ( result.runCount() == 1 ? "" : "s") + ")" );
           }
           else
           {
               trace( "" );
               trace( "FAILURES!!!" );
               trace( "Tests run: " + result.runCount() +
                            ",  Failures: " + result.failureCount() +
                            ",  Errors: " + result.errorCount() );
           }
          trace( "" );
       },

   //------------------------------------------------------------------------------

       "public function addError",function addError( test/*:Test*/, error/*:Error*/ )/*:void*/
       {
           this.updateProgress$1( "E" );
       },

   //------------------------------------------------------------------------------

       "public function addFailure",function addFailure( test/*:Test*/, error/*:AssertionFailedError*/ )/*:void*/
       {
           this.updateProgress$1( "F" );
       },

   //------------------------------------------------------------------------------

       "public function endTest",function endTest( test/*:Test*/ )/*:void*/
       {
       },

   //------------------------------------------------------------------------------

       "public function startTest",function startTest( test/*:Test*/ )/*:void*/
       {
           this.updateProgress$1( "." );
       },

   //------------------------------------------------------------------------------
       "private function updateProgress",function updateProgress( lr/*:String*/ )/*:void*/
       {
           this._progress$1 = this._progress$1 + lr;
           if ( this._progress$1.length > 40 )
           {
               trace( this._progress$1 );
               this._progress$1 = "";
           }
       },

   //------------------------------------------------------------------------------

       "private var",{ _progress/*:String*/:null},
   ];},[],["flexunit.framework.TestListener","flexunit.textui.Printer","flexunit.framework.TestFailure"], "0.8.0", "0.9.5"
);

==> joounit-1.0.0.jar: joo/classes/flexunit/textui/ResultPrinter.js <==
joo.classLoader.prepare(/*
	Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.textui",/*
{

   import flash.utils.*;
   import flexunit.framework.*;
   import flexunit.utils.*;*/

   "public class ResultPrinter implements flexunit.framework.TestListener, flexunit.textui.Printer",1,function($$private){var trace=joo.trace,$1=flexunit.framework;return[
   
       "public function ResultPrinter",function ResultPrinter()
       {/*
           super()*/;
           this._progress$1 = "";
       },

   //------------------------------------------------------------------------------

       "public function print",function print( result/*:TestResult*/, runTime/*:Number*/ )/*:void*/
       {
           if ( this._progress$1.length > 0 )
               trace( this._progress$1 );

           this.printHeader(runTime);
           this.printErrors(result);
           this.printFailures(result);
           this.printFooter$1(result);
       },

   //------------------------------------------------------------------------------

       "public function printHeader",function printHeader( runTime/*:Number*/ )/*:void*/
       {
           trace( "Time: " + ( runTime / 1000 ) + " seconds" );
       },

   //------------------------------------------------------------------------------

       "public function printErrors",function printErrors( result/*:TestResult*/ )/*:void*/
       {
           this.printDefects( result.errorsIterator(), result.errorCount(), "error" );
       },

   //------------------------------------------------------------------------------

       "public function printFailures",function printFailures( result/*:TestResult*/ )/*:void*/
       {
           this.printDefects( result.failuresIterator(), result.failureCount(), "failure" );
       },

   //------------------------------------------------------------------------------

       "public function printDefects",function printDefects( defects/*:Iterator*/, count/*:Number*/, type/*:String*/ )/*:void*/
       {
           if ( count == 0 )
               return;

           if ( count == 1 )
               trace( "There was " + count + " " + type + ":" );
           else
               trace( "There were " + count + " " + type + "s:");

           for ( var i/*:Number*/ = 1; defects.hasNext(); i++)
           {
               this.printDefect$1(/* TestFailure*/( defects.next() ), i );
           }
       },

   //------------------------------------------------------------------------------

       "private function printDefect",function printDefect( defect/*:TestFailure*/, count/*:Number*/ )/*:void*/
       {
           this.printDefectHeader$1( defect, count );
           this.printDefectTrace$1( defect );
       },

   //------------------------------------------------------------------------------

       "private function printDefectHeader",function printDefectHeader( defect/*:TestFailure*/, count/*:Number*/ )/*:void*/
       {
           trace( count + ") " + defect.failedTest().toString() );
       },

   //------------------------------------------------------------------------------

       "private function printDefectTrace",function printDefectTrace( defect/*:TestFailure*/ )/*:void*/
       {
           trace( "\t" + defect.exceptionMessage() );
       },

   //------------------------------------------------------------------------------

       "private function printFooter",function printFooter( result/*:TestResult*/ )/*:void*/
       {
           if ( result.wasSuccessful() )
           {
               trace( "" );
               trace( "OK (" + result.runCount() + " test" + ( result.runCount() == 1 ? "" : "s") + ")" );
           }
           else
           {
               trace( "" );
               trace( "FAILURES!!!" );
               trace( "Tests run: " + result.runCount() +
                            ",  Failures: " + result.failureCount() +
                            ",  Errors: " + result.errorCount() );
           }
          trace( "" );
       },

   //------------------------------------------------------------------------------

       "public function addError",function addError( test/*:Test*/, error/*:Error*/ )/*:void*/
       {
           this.updateProgress$1( "E" );
       },

   //------------------------------------------------------------------------------

       "public function addFailure",function addFailure( test/*:Test*/, error/*:AssertionFailedError*/ )/*:void*/
       {
           this.updateProgress$1( "F" );
       },

   //------------------------------------------------------------------------------

       "public function endTest",function endTest( test/*:Test*/ )/*:void*/
       {
       },

   //------------------------------------------------------------------------------

       "public function startTest",function startTest( test/*:Test*/ )/*:void*/
       {
           this.updateProgress$1( "." );
       },

   //------------------------------------------------------------------------------
       "private function updateProgress",function updateProgress( lr/*:String*/ )/*:void*/
       {
           this._progress$1 = this._progress$1 + lr;
           if ( this._progress$1.length > 40 )
           {
               trace( this._progress$1 );
               this._progress$1 = "";
           }
       },

   //------------------------------------------------------------------------------

       "private var",{ _progress/*:String*/:null},
   undefined];},[],["flexunit.framework.TestListener","flexunit.textui.Printer","flexunit.framework.TestFailure"], "0.8.0", "1.0.0"
);
